@@ -16,8 +16,7 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
     }
 
     def __init__(self, *args, **kwargs):
-        self.init_logging()
-        self.init_rollbar(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         self.asset_id = None
         self.event = None
@@ -229,14 +228,14 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
 
         for module_type in self.get_modules():
             try:
-                module = module_type(self.state)
+                module = module_type(self.state, rollbar=self.rollbar)
             except Exception:
                 raise exceptions.Misconfigured("Module {0} not able to initialize for asset_id {1}".format(module_type, self.asset_id))
 
             try:
                 module.run(self.event)
-            except Exception as ex:
-                self.rollbar.report_exc_info(ex)
+            except Exception:
+                self.track_error(message=f"Error in module {module_type.module_key}")
 
         last_processed_timestamp = self.event[-1].get('timestamp')
         self.state['last_processed_timestamp'] = last_processed_timestamp
