@@ -143,7 +143,7 @@ class ActivityModule(Module):
         self.set_state('active_string_id', active_string_id)
 
         if active_string_type == 'drillstring':
-            drillstring = operations.get_config_by_id('data.drillstring', active_string_id)
+            drillstring = API().get_by_id(path="/v1/data/corva/", collection='data.drillstring', id=active_string_id).data
             if drillstring:
                 drillstring_number = drillstring.get('data', {}).get('id', None)
                 self.set_state('drillstring_number', drillstring_number)
