@@ -76,6 +76,12 @@ class API(object):
         return result
 
     def get_by_id(self, path, **kwargs):
+        """
+        Get a document with the given kwargs ('collection', 'id')
+        :param path: API path
+        :param kwargs: 'collection' and 'id' kwargs are required
+        :return: a result object
+        """
         collection = kwargs.pop("collection", None)
         component_id = kwargs.pop("id", None)
         path = "{0}{1}{2}/{3}".format(self.api_url, path, collection, component_id)
