@@ -1,3 +1,5 @@
+from worker.data.operations import get_data_by_path
+
 parameters = {
     "global": {
         "app-name": "my-app",
@@ -8,28 +10,8 @@ parameters = {
 }
 
 
-def get(key, default=None):
-    if not key:
-        if default:
-            return default
-
-        raise KeyError("No key provided")
-
-    path = key.split(".")
-    value = parameters
-
-    while path:
-        current_key = path.pop(0)
-
-        if current_key not in value:
-            if default:
-                return default
-
-            raise KeyError("{0} not found in path".format(current_key))
-
-        value = value.get(current_key)
-
-    return value
+def get(path, default=None):
+    return get_data_by_path(data=parameters, path=path, default=default)
 
 
 def update(additional_parameters):
