@@ -7,7 +7,7 @@ from worker.data.operations import is_number
 
 class RedisMixin(object):
     def __init__(self, *args, **kwargs):
-        pass
+        super().__init__(*args, **kwargs)
 
     def get_redis(self):
         if not getattr(self, 'redis', None):
@@ -56,7 +56,7 @@ class LoggingMixin(object):
         "off"
     ]
 
-    def init_logging(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs):
         self.logging_level = os.getenv("LOGGING_LEVEL", "info").lower()
         self.logging_asset_id = os.getenv("LOGGING_ASSET_ID", 0)
 
@@ -66,6 +66,8 @@ class LoggingMixin(object):
         if is_number(self.logging_asset_id):
             self.logging_asset_id = int(self.logging_asset_id)
 
+        super().__init__(*args, **kwargs)
+
     def all(self, asset_id, text):
         self.call('all', asset_id, text)
 
@@ -98,11 +100,11 @@ class LoggingMixin(object):
 
 
 class RollbarMixin(object):
-    def init_rollbar(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs):
         self.rollbar = kwargs.pop('rollbar', None)
         super().__init__(*args, **kwargs)
 
-    def track_error(self, message: str, level: str):
+    def track_message(self, message: str, level: str):
         # Levels: critical, error, warning, info, debug, and ignored
         if not self.rollbar:
             return
@@ -110,3 +112,9 @@ class RollbarMixin(object):
         level = level.lower()
 
         self.rollbar.report_message(message, level)
+
+    def track_error(self, message: str = None):
+        if not self.rollbar:
+            return
+
+        self.rollbar.report_exc_info(extra_data=message, level='error')
